@@ -7,13 +7,14 @@
 
 import sys
 
-if __package__ is None and not hasattr(sys, 'frozen'):
+if __package__ is None and not hasattr(sys, "frozen"):
     # direct call of __main__.py
     import os.path
+
     path = os.path.realpath(os.path.abspath(__file__))
     sys.path.insert(0, os.path.dirname(os.path.dirname(path)))
 
 import myrich
 
-if __name__ == '__main__':
-    myrich.main()
\ No newline at end of file
+if __name__ == "__main__":
+    myrich.main()
